<nav class="navbar navbar-expand-lg bg-body-tertiary position-absolute start-50">
    {% if current_user.is_authenticated %}
    <div class="container-fluid">
        <a class="nav-link" href="{{url_for('index')}}">Home</a>
    </div>
    <div class="container-fluid">
        <a class="nav-link" href="{{url_for('logout')}}">Logout</a>
    </div>

    {% else %}
    <div class="container-fluid">
        <a class="nav-link" href="{{url_for('login')}}">Login</a>
    </div>
    <div class="container-fluid">
        <a class="nav-link" href="{{url_for('register')}}">Register</a>
    </div>
    {% endif %}
</nav>