{% extends 'base.html' %}

{% block content %}

<form method="post" action="/addcar">
    <div class="container text-center">
        <div class="row">
            <div class="col">
                Car brand
            </div>
            <div class="col">
                <input type="text" name="brand" required/>
            </div>
            <div class="col">
                Model
            </div>
            <div class="col">
                <input type="text" name="model" required/>
            </div>
            <div class="col">
                Type
            </div>
            <div class="col">
                <select id="ffff" name="car_type">
                    <option value="Plug-in">Plug-in</option>
                    <option value="Benzina">Benzina</option>
                    <option value="Diesel">Diesel</option>
                </select>
            </div>
            <div class="col">
                <input type="submit" name="filter"/>
            </div>
        </div>
    </div>

</form>

{% endblock %}
