{% extends 'base.html' %}
aaaaa
{% block content %}

<head>Register</head>

<form method="post" action="/register">
    User Name
    <input type="text" name="username" required/>
    Password
    <input type="password" name="password" required/>
<!--    Car Brand-->
<!--    <input type="text" name="car_brand" required/>-->
<!--    Car Model-->
<!--    <input type="text" name="car_model" required/>-->

    <input type="submit"/>

</form>
<br>

{% endblock %}
