{% extends 'base.html' %}

{% block content %}

<form method="post" action="/importtable" enctype="multipart/form-data">
    <div class="container text-center">
        <div class="row">
            <div class="col">
                <label>File</label>
                <input type="file" name="myfile">
            </div>
            <div class="col">
                <input type="submit" name="import_table"/>
            </div>
        </div>
    </div>
</form>


{% endblock %}
